/************************************************************************************************/
/**
* @file               std_rcc.h
* @author             MCU Ecosystem Development Team
* @brief              RCC STD库驱动头文件。
*                     提供RCC相关的STD库操作函数声明、数据类型以及常量的定义。                         
*                     
*
**************************************************************************************************
* @attention
* Copyright (c) CEC Huada Electronic Design Co.,Ltd. All rights reserved.
*
**************************************************************************************************
*/

/*避免头文件重复引用*/
#ifndef STD_RCC_H
#define STD_RCC_H

/************************************************************************************************/
/** 
* @addtogroup STD_Driver
* @{
*/

/**
* @defgroup RCC RCC
* @brief 复位和时钟控制器的STD库驱动
* @{
*/
/************************************************************************************************/


#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------includes--------------------------------------------*/
#include "std_common.h"


/*--------------------------------------------define--------------------------------------------*/
/************************************************************************************************/
/**
* @defgroup RCC_Constants RCC Constants 
* @brief  RCC常量定义及宏定义
* @{
*
*/
/************************************************************************************************/
/* LXTAL配置参数定义 */
#define RCC_LXTAL_ON                       (0x00000001UL)                           /**< LXTAL时钟开启        */
#define RCC_LXTAL_BYPASS                   (0x00000002UL)                           /**< LXTAL为外部时钟模式  */ 

/* RCH时钟定义 */
#define RCC_RCH_FREQ_4M                    RCC_CSR1_RCHFREQ_RCH4                    /**< RCH时钟为4MHz      */
#define RCC_RCH_FREQ_16M                   RCC_CSR1_RCHFREQ_RCH16                   /**< RCH时钟为16MHz     */
#define RCC_RCH_FREQ_48M                   RCC_CSR1_RCHFREQ_RCH48                   /**< RCH时钟为48MHz     */

/* 系统时钟源选择 */
#define RCC_SYSCLK_SRC_RCH                 RCC_CFG_SYSW_RCH                         /**< 选择RCH作为系统时钟源      */
#define RCC_SYSCLK_SRC_RCL                 RCC_CFG_SYSW_RCL                         /**< 选择RCL作为系统时钟源      */
#define RCC_SYSCLK_SRC_LXTAL               RCC_CFG_SYSW_LXTAL                       /**< 选择LXTAL作为系统时钟源    */

/* 系统时钟源状态定义 */
#define RCC_SYSCLK_SRC_STATUS_RCH          RCC_CFG_SYSWS_RCH                        /**< 系统时钟为RCH      */
#define RCC_SYSCLK_SRC_STATUS_RCL          RCC_CFG_SYSWS_RCL                        /**< 系统时钟为RCL      */
#define RCC_SYSCLK_SRC_STATUS_LXTAL        RCC_CFG_SYSWS_LXTAL                      /**< 系统时钟为LXTAL    */

/* AHB时钟分频参数定义 */
#define RCC_HCLK_DIV1                      RCC_CFG_HPRE_1                           /**< HCLK不分频         */
#define RCC_HCLK_DIV2                      RCC_CFG_HPRE_2                           /**< HCLK分频因子 = 2   */
#define RCC_HCLK_DIV4                      RCC_CFG_HPRE_4                           /**< HCLK分频因子 = 4   */
#define RCC_HCLK_DIV8                      RCC_CFG_HPRE_8                           /**< HCLK分频因子 = 8   */
#define RCC_HCLK_DIV16                     RCC_CFG_HPRE_16                          /**< HCLK分频因子 = 16  */
#define RCC_HCLK_DIV32                     RCC_CFG_HPRE_32                          /**< HCLK分频因子 = 32  */
#define RCC_HCLK_DIV64                     RCC_CFG_HPRE_64                          /**< HCLK分频因子 = 64  */
#define RCC_HCLK_DIV128                    RCC_CFG_HPRE_128                         /**< HCLK分频因子 = 128 */

/* APB时钟分频参数定义 */
#define RCC_PCLK_DIV1                      RCC_CFG_PPRE_1                           /**< APB总线时钟不分频        */
#define RCC_PCLK_DIV2                      RCC_CFG_PPRE_2                           /**< APB总线时钟分频因子 = 2  */
#define RCC_PCLK_DIV4                      RCC_CFG_PPRE_4                           /**< APB总线时钟分频因子 = 4  */
#define RCC_PCLK_DIV8                      RCC_CFG_PPRE_8                           /**< APB总线时钟分频因子 = 8  */
#define RCC_PCLK_DIV16                     RCC_CFG_PPRE_16                          /**< APB总线时钟分频因子 = 16 */
        
/* MCO时钟源参数定义 */                                                                            
#define RCC_MCO_SRC_DISABLE                RCC_CFG_MCOSEL_DISABLE                   /**< MCO输出无效         */
#define RCC_MCO_SRC_SYSCLK                 RCC_CFG_MCOSEL_SYSCLK                    /**< MCO选择SYSCLK输出   */
#define RCC_MCO_SRC_RCH                    RCC_CFG_MCOSEL_RCH                       /**< MCO选择RCH输出      */
#define RCC_MCO_SRC_RCL                    RCC_CFG_MCOSEL_RCL                       /**< MCO选择RCL输出      */
#define RCC_MCO_SRC_LXTAL                  RCC_CFG_MCOSEL_LXTAL                     /**< MCO选择LXTAL输出    */

/* MCO时钟分频参数定义 */
#define RCC_MCO_DIV1                       RCC_CFG_MCOPRE_DIV1                      /**< MCO不分频         */
#define RCC_MCO_DIV2                       RCC_CFG_MCOPRE_DIV2                      /**< MCO分频因子 = 2   */
#define RCC_MCO_DIV4                       RCC_CFG_MCOPRE_DIV4                      /**< MCO分频因子 = 4   */
#define RCC_MCO_DIV8                       RCC_CFG_MCOPRE_DIV8                      /**< MCO分频因子 = 8   */
#define RCC_MCO_DIV16                      RCC_CFG_MCOPRE_DIV16                     /**< MCO分频因子 = 16  */
#define RCC_MCO_DIV32                      RCC_CFG_MCOPRE_DIV32                     /**< MCO分频因子 = 32  */
#define RCC_MCO_DIV64                      RCC_CFG_MCOPRE_DIV64                     /**< MCO分频因子 = 64  */
#define RCC_MCO_DIV128                     RCC_CFG_MCOPRE_DIV128                    /**< MCO分频因子 = 128 */

/* RCC中断控制位定义 */
#define RCC_INTERRUPT_LXTAL_CSS            RCC_IER_LXTAL_CSSIE                      /**< LXTAL CSS中断控制位   */

/* RCC中断标志位定义 */
#define RCC_FLAG_LXTAL_CSS                 RCC_ISR_LXTAL_CSSF                       /**< LXTAL CSS中断标志位   */

/* RCC清除控制位定义 */
#define RCC_CLEAR_LXTAL_CSS                RCC_ICR_LXTAL_CSSC                       /**< LXTAL CSS清除控制位   */

/* LXTAL驱动模式参数定义 */
#define RCC_LXTAL_DRIVE_MODE_NORMAL       (0x00000000UL)                            /**< LXTAL驱动能力为普通型   */
#define RCC_LXTAL_DRIVE_MODE_ENHANCE      (RCC_AWCR_LXTAL_DRV_MODE)                 /**< LXTAL驱动能力为增强型   */

/* LXTAL驱动参数配置定义 */
#define RCC_LXTAL_DRIVE_LEVEL0            RCC_AWCR_LXTAL_DRV_0                     /**< LXTAL低驱动能力       */
#define RCC_LXTAL_DRIVE_LEVEL1            RCC_AWCR_LXTAL_DRV_1                     /**< LXTAL中低驱动能力     */
#define RCC_LXTAL_DRIVE_LEVEL2            RCC_AWCR_LXTAL_DRV_2                     /**< LXTAL中高驱动能力     */
#define RCC_LXTAL_DRIVE_LEVEL3            RCC_AWCR_LXTAL_DRV_3                     /**< LXTAL高驱动能力       */

/* LXTAL时钟稳定周期数定义 */
#define RCC_LXTAL_STAB_SEL_256           (0x00000000UL)                            /**< LXTAL时钟稳定周期为256个时钟周期    */
#define RCC_LXTAL_STAB_SEL_1024          (0x1UL << RCC_AWCR_LXTAL_STAB_SEL_POS)    /**< LXTAL时钟稳定周期为1024个时钟周期   */
#define RCC_LXTAL_STAB_SEL_4096          (0x2UL << RCC_AWCR_LXTAL_STAB_SEL_POS)    /**< LXTAL时钟稳定周期为4096个时钟周期   */
#define RCC_LXTAL_STAB_SEL_16384         (0x3UL << RCC_AWCR_LXTAL_STAB_SEL_POS)    /**< LXTAL时钟稳定周期为16384个时钟周期  */

/* IO端口时钟选择 */
#define RCC_PERIPH_CLK_GPIOA              RCC_IOPEN_GPIOAEN                        /**< GPIOA 时钟控制位  */
#define RCC_PERIPH_CLK_GPIOB              RCC_IOPEN_GPIOBEN                        /**< GPIOB 时钟控制位  */
#define RCC_PERIPH_CLK_GPIOF              RCC_IOPEN_GPIOFEN                        /**< GPIOF 时钟控制位  */

/* IO端口复位选择 */
#define RCC_PERIPH_RESET_GPIO_ALL         RCC_IOPRST_GPIOA_RST | RCC_IOPRST_GPIOB_RST  \
                                                               | RCC_IOPRST_GPIOF_RST     /**< GPIO所有端口复位控制位 */
                                                               
#define RCC_PERIPH_RESET_GPIOA            RCC_IOPRST_GPIOA_RST                            /**< GPIOA端口复位控制位    */
#define RCC_PERIPH_RESET_GPIOB            RCC_IOPRST_GPIOB_RST                            /**< GPIOB端口复位控制位    */
#define RCC_PERIPH_RESET_GPIOF            RCC_IOPRST_GPIOF_RST                            /**< GPIOF端口复位控制位    */

/* AHB外设时钟选择 */
#define RCC_PERIPH_CLK_DMA                RCC_AHBEN_DMAEN                                 /**< AHB外设DMA时钟控制位   */
#define RCC_PERIPH_CLK_CRC                RCC_AHBEN_CRCEN                                 /**< AHB外设CRC时钟控制位  */

/* AHB外设复位选择 */
#define RCC_PERIPH_RESET_AHB              RCC_AHBRST_DMA_RST | RCC_AHBRST_CRC_RST         /**< AHB所有外设复位控制位  */
                                                                                                                      
#define RCC_PERIPH_RESET_DMA              RCC_AHBRST_DMA_RST                              /**< AHB外设DMA复位控制位   */
#define RCC_PERIPH_RESET_CRC              RCC_AHBRST_CRC_RST                              /**< AHB外设CRC复位控制位   */

/* APB外设时钟选择 */
#define RCC_PERIPH_CLK_TIM3               RCC_APBEN1_TIM3EN                               /**< APB外设TIM3时钟控制位      */
#define RCC_PERIPH_CLK_TIM8               RCC_APBEN1_TIM8EN                               /**< APB外设TIM8时钟控制位      */
#define RCC_PERIPH_CLK_RTC                RCC_APBEN1_RTCAPBEN                             /**< APB外设RTC APB时钟控制位   */
#define RCC_PERIPH_CLK_SPI2               RCC_APBEN1_SPI2EN                               /**< APB外设SPI2时钟控制位      */
#define RCC_PERIPH_CLK_UART2              RCC_APBEN1_UART2EN                              /**< APB外设UART2时钟控制位     */
#define RCC_PERIPH_CLK_LPUART1            RCC_APBEN1_LPUART1EN                            /**< APB外设LPUART1时钟控制位   */
#define RCC_PERIPH_CLK_I2C1               RCC_APBEN1_I2C1EN                               /**< APB外设I2C1时钟控制位      */
#define RCC_PERIPH_CLK_PMU                RCC_APBEN1_PMUEN                                /**< APB外设PMU时钟控制位       */
#define RCC_PERIPH_CLK_LPTIM1             RCC_APBEN1_LPTIM1EN                             /**< APB外设LPTIM1时钟控制位    */

#define RCC_PERIPH_CLK_COMP               RCC_APBEN2_COMPEN                               /**< APB外设COMP时钟控制位      */
#define RCC_PERIPH_CLK_TIM1               RCC_APBEN2_TIM1EN                               /**< APB外设TIM1时钟控制位      */
#define RCC_PERIPH_CLK_SPI1               RCC_APBEN2_SPI1EN                               /**< APB外设SPI1时钟控制位      */
#define RCC_PERIPH_CLK_UART1              RCC_APBEN2_UART1EN                              /**< APB外设UART1时钟控制位     */
#define RCC_PERIPH_CLK_ADC                RCC_APBEN2_ADCEN                                /**< APB外设ADC时钟控制位       */
#define RCC_PERIPH_CLK_DBG                RCC_APBEN2_DBGEN                                /**< APB外设DBG时钟控制位       */                                                                                                                        

/* APB外设1复位选择 */
#define RCC_PERIPH_RESET_APB1             RCC_APBRST1_TIM3_RST | RCC_APBRST1_TIM8_RST     \
                                                               | RCC_APBRST1_SPI2_RST     \
                                                               | RCC_APBRST1_UART2_RST    \
                                                               | RCC_APBRST1_LPUART1_RST  \
                                                               | RCC_APBRST1_I2C1_RST     \
                                                               | RCC_APBRST1_LPTIM1_RST      /**< APB外设1复位控制位           */

#define RCC_PERIPH_RESET_TIM3             RCC_APBRST1_TIM3_RST                               /**< APB外设1的TIM3复位控制位     */
#define RCC_PERIPH_RESET_TIM8             RCC_APBRST1_TIM8_RST                               /**< APB外设1的TIM8复位控制位     */
#define RCC_PERIPH_RESET_SPI2             RCC_APBRST1_SPI2_RST                               /**< APB外设1的SPI2时复位制位     */
#define RCC_PERIPH_RESET_UART2            RCC_APBRST1_UART2_RST                              /**< APB外设1的UART2复位控制位    */
#define RCC_PERIPH_RESET_LPUART1          RCC_APBRST1_LPUART1_RST                            /**< APB外设1的LPUART1复位控制位  */
#define RCC_PERIPH_RESET_I2C1             RCC_APBRST1_I2C1_RST                               /**< APB外设1的I2C1复位控制位     */
#define RCC_PERIPH_RESET_LPTIM1           RCC_APBRST1_LPTIM1_RST                             /**< APB外设1的LPTIM1复位控制位   */
                   
/* APB外设2复位选择 */
#define RCC_PERIPH_RESET_APB2             RCC_APBRST2_COMP_RST | RCC_APBRST2_TIM1_RST     \
                                                               | RCC_APBRST2_SPI1_RST     \
                                                               | RCC_APBRST2_UART1_RST    \
                                                               | RCC_APBRST2_ADC_RST      \
                                                               | RCC_APBRST2_DBG_RST         /**< APB外设1复位控制位          */
                                                                                                                               
#define RCC_PERIPH_RESET_COMP               RCC_APBRST2_COMP_RST                             /**< APB外设2的COMP时复位制位    */
#define RCC_PERIPH_RESET_TIM1               RCC_APBRST2_TIM1_RST                             /**< APB外设2的TIM1时复位制位    */
#define RCC_PERIPH_RESET_SPI1               RCC_APBRST2_SPI1_RST                             /**< APB外设2的SPI1复位控制位    */
#define RCC_PERIPH_RESET_UART1              RCC_APBRST2_UART1_RST                            /**< APB外设2的USART复位控制位   */
#define RCC_PERIPH_RESET_ADC                RCC_APBRST2_ADC_RST                              /**< APB外设2的ADC复位控制位     */
#define RCC_PERIPH_RESET_DBG                RCC_APBRST2_DBG_RST                              /**< APB外设2的DBG复位控制位     */

/* LPUART1异步时钟源选择 */
#define RCC_LPUART1_ASYNC_CLK_SRC_PCLK          RCC_CLKSEL_LPUART1_SEL_PCLK            /**< PCLK时钟作为LPUART1时钟      */
#define RCC_LPUART1_ASYNC_CLK_SRC_SYSCLK        RCC_CLKSEL_LPUART1_SEL_SYSCLK          /**< SYSCLK时钟作为LPUART1时钟    */
#define RCC_LPUART1_ASYNC_CLK_SRC_RCH           RCC_CLKSEL_LPUART1_SEL_RCH             /**< RCH时钟作为LPUART1时钟       */
#define RCC_LPUART1_ASYNC_CLK_SRC_LXTAL         RCC_CLKSEL_LPUART1_SEL_LXTAL           /**< LXTAL时钟作为LPUART1时钟     */

/* LPTIM1异步时钟源选择 */
#define RCC_LPTIM1_ASYNC_CLK_SRC_PCLK           RCC_CLKSEL_LPTIM1_SEL_PCLK             /**< PCLK时钟作为LPTIM1时钟      */
#define RCC_LPTIM1_ASYNC_CLK_SRC_RCL            RCC_CLKSEL_LPTIM1_SEL_RCL              /**< RCL时钟作为LPTIM1时钟       */
#define RCC_LPTIM1_ASYNC_CLK_SRC_MCO            RCC_CLKSEL_LPTIM1_SEL_MCO              /**< MCO时钟作为LPTIM1时钟       */
#define RCC_LPTIM1_ASYNC_CLK_SRC_LXTAL          RCC_CLKSEL_LPTIM1_SEL_LXTAL            /**< LXTAL时钟作为LPTIM1时钟     */
                                                                                       
/* RTC异步时钟源选择 */     
#define RCC_RTC_ASYNC_CLK_SRC_NONE              RCC_AWCR_RTCSEL_NONE                   /**< RTC无时钟                    */                                                                                       
#define RCC_RTC_ASYNC_CLK_SRC_LXTAL             RCC_AWCR_RTCSEL_LXTAL                  /**< RTC时钟为LXTAL               */
#define RCC_RTC_ASYNC_CLK_SRC_RCL               RCC_AWCR_RTCSEL_RCL                    /**< RTC时钟为RCL                 */

/* 复位标志定义 */
#define RCC_RESET_FLAG_LOCKUP                   RCC_CSR2_LOCKUP_RSTF                   /**< LOCKUP复位标志           */
#define RCC_RESET_FLAG_NRST                     RCC_CSR2_NRST_RSTF                     /**< NRST引脚复位标志         */
#define RCC_RESET_FLAG_POR                      RCC_CSR2_POR_RSTF                      /**< POR复位标志              */
#define RCC_RESET_FLAG_SW                       RCC_CSR2_SW_RSTF                       /**< 软件复位标志             */
#define RCC_RESET_FLAG_IWDG                     RCC_CSR2_IWDG_RSTF                     /**< IWDG复位标志             */
#define RCC_RESET_FLAG_PVD                      RCC_CSR2_PVD_RSTF                      /**< PVD复位标志              */
#define RCC_RESET_FLAG_ALL                      (0x7BUL<<RCC_CSR2_PVD_RSTF_POS)        /**< 所有复位标志             */

/* NRST端口功能参数定义 */
#define RCC_NRST_PIN_NRST                       (0x00000000UL)                         /**< PF3引脚作为NRST端口      */
#define RCC_NRST_PIN_GPIO                       RCC_CSR2_NRST_MODE                     /**< PF3引脚作为GPIO端口      */



/** 
* @} 
*/

/*-------------------------------------------functions------------------------------------------*/

/************************************************************************************************/
/**
* @defgroup RCC_External_Functions RCC External Functions
* @brief    RCC对外函数
* @{
*
*/
/************************************************************************************************/
/** 
* @brief  使能RCH时钟
* @note   使能RCH后，软件应等待RCHRDY标志置位后，再使用该时钟
* @retval 无
*/
__STATIC_INLINE void std_rcc_rch_enable(void)
{
    RCC->CSR1 |= RCC_CSR1_RCHON;
} 

/** 
* @brief  关闭RCH时钟
* @note   如果RCH为系统时钟源，则其不能被停止。此时用户应先将系统时钟源切换为其他时钟，再关闭该时钟源
* @note   当关闭RCH时，需等待RCHRDY标志清零
* @retval 无
*/
__STATIC_INLINE void std_rcc_rch_disable(void)
{
    RCC->CSR1 &= (~RCC_CSR1_RCHON);
}

/** 
* @brief  获取RCH ready标志
* @retval bool 返回逻辑表达式的判断结果
*             @arg true： 表示RCH ready置位
*             @arg false：表示RCH ready未置位
*/
__STATIC_INLINE bool std_rcc_get_rch_ready(void) 
{
    return((RCC->CSR1 & RCC_CSR1_RCHRDY) == RCC_CSR1_RCHRDY);
}        


/** 
* @brief  配置RCH时钟源
* @param  rchsource 定义RCH时钟源
*             @arg  RCC_RCH_FREQ_4M： RCH时钟为4MHz
*             @arg  RCC_RCH_FREQ_16M：RCH时钟为16MHz
*             @arg  RCC_RCH_FREQ_48M：RCH时钟为48MHz
* @retval 无
*/
__STATIC_INLINE void std_rcc_set_rch_source(uint32_t rchsource)
{
    MODIFY_REG(RCC->CSR1, RCC_CSR1_RCHFREQ, (rchsource));
}


/** 
* @brief  获取RCH时钟源
* @retval uint32_t RCH时钟源参数
*             @arg  RCC_RCH_FREQ_4M： RCH时钟为4MHz
*             @arg  RCC_RCH_FREQ_16M：RCH时钟为16MHz
*             @arg  RCC_RCH_FREQ_48M：RCH时钟为48MHz
*/
__STATIC_INLINE uint32_t std_rcc_get_rch_source(void)
{
    return(RCC->CSR1 & RCC_CSR1_RCHFREQ);
}


/** 
* @brief  设置系统时钟源
* @param  clocksource 系统时钟源
*             @arg RCC_SYSCLK_SRC_RCH
*             @arg RCC_SYSCLK_SRC_RCL     
*             @arg RCC_SYSCLK_SRC_LXTAL
* @retval 无
*/
__STATIC_INLINE void std_rcc_set_sysclk_source(uint32_t clocksource)
{
    MODIFY_REG(RCC->CFG, RCC_CFG_SYSW, clocksource);
}    

/** 
* @brief  获取系统时钟源信息
* @retval uint32_t 系统时钟源
*             @arg RCC_SYSCLK_SRC_STATUS_RCH
*             @arg RCC_SYSCLK_SRC_STATUS_RCL    
*             @arg RCC_SYSCLK_SRC_STATUS_LXTAL    
*/
__STATIC_INLINE uint32_t std_rcc_get_sysclk_source(void)
{
    return(RCC->CFG & RCC_CFG_SYSWS);
}    

/** 
* @brief  设置AHB时钟分频因子
* @param  ahb_div AHB分频因子
*             @arg RCC_HCLK_DIV1   
*             @arg RCC_HCLK_DIV2     
*             @arg ...   
*             @arg RCC_HCLK_DIV128
* @retval 无
*/
__STATIC_INLINE void std_rcc_set_ahbdiv(uint32_t ahb_div)
{
    MODIFY_REG(RCC->CFG, RCC_CFG_HPRE, ahb_div);
}    

/** 
* @brief  获取AHB时钟分频因子
* @retval uint32_t HCLK时钟分频因子
*             @arg RCC_HCLK_DIV1   
*             @arg RCC_HCLK_DIV2     
*             @arg ...   
*             @arg RCC_HCLK_DIV128
*/
__STATIC_INLINE uint32_t std_rcc_get_ahbdiv(void)
{
    return(RCC->CFG & RCC_CFG_HPRE);
} 

/** 
* @brief  设置APB时钟分频因子
* @param  apb_div APB分频因子
*             @arg RCC_PCLK_DIV1   
*             @arg RCC_PCLK_DIV2     
*             @arg ...   
*             @arg RCC_PCLK_DIV16
* @retval 无
*/
__STATIC_INLINE void std_rcc_set_apbdiv(uint32_t apb_div)
{
    MODIFY_REG(RCC->CFG, RCC_CFG_PPRE, apb_div);
}    

/** 
* @brief  获取APB时钟分频因子
* @retval uint32_t PCLK1时钟分频因子
*             @arg RCC_PCLK_DIV1   
*             @arg RCC_PCLK_DIV2     
*             @arg ...   
*             @arg RCC_PCLK_DIV16
*/
__STATIC_INLINE uint32_t std_rcc_get_apbdiv(void)
{
    return(RCC->CFG & RCC_CFG_PPRE);
} 

/**
* @brief  配置MCO输出信息
* @param  mco_source MCO输出源选择
*             @arg RCC_MCO_SRC_DISABLE
*             @arg RCC_MCO_SRC_SYSCLK
*             @arg RCC_MCO_SRC_RCH
*             @arg RCC_MCO_SRC_RCL
*             @arg RCC_MCO_SRC_LXTAL
* @param  mco_psc MCO输出分频因子
*             @arg RCC_MCO_DIV1
*             @arg RCC_MCO_DIV2
*             @arg ...
*             @arg RCC_MCO_DIV128
* @retval 无
*/
__STATIC_INLINE void std_rcc_mco_config(uint32_t mco_source, uint32_t mco_psc)
{
    MODIFY_REG(RCC->CFG, RCC_CFG_MCOSEL | RCC_CFG_MCOPRE, mco_source | mco_psc);
}


/** 
* @brief  使能LXTAL时钟
* @param  mode LXTAL的旁路模式选择
*             @arg RCC_LXTAL_ON：    使能晶体模式
*             @arg RCC_LXTAL_BYPASS：使能外部时钟模式
* @note   使能LXTAL后，软件应等待LXTALRDY标志置位后，再使用该时钟
* @note   调用该函数前应先调用std_pmu_vaon_write_enable(void)，解除RCC_AWCR的写保护
* @retval 无
*/
__STATIC_INLINE void std_rcc_lxtal_enable(uint32_t mode)
{
    if(mode == RCC_LXTAL_BYPASS)
    {
        RCC->AWCR |= RCC_AWCR_LXTALBYP; 
    }
    else
    {
        RCC->AWCR &= ~RCC_AWCR_LXTALBYP; 
    }
    RCC->AWCR |= RCC_AWCR_LXTALON; 
}                   


/** 
* @brief  关闭LXTAL时钟
* @note   如果LXTAL为系统时钟源，则其不能被停止。此时用户应先将系统时钟源切换为其他时钟，再关闭该时钟源
* @note   当关闭LXTAL时，需等待LXTALRDY标志清零
* @note   调用该函数前应先调用std_pmu_vaon_write_enable(void)，解除RCC_AWCR的写保护
* @retval 无
*/
__STATIC_INLINE void std_rcc_lxtal_disable(void) 
{
    RCC->AWCR &= (~RCC_AWCR_LXTALON);
}


/** 
* @brief  获取LXTAL ready标志
* @retval bool 返回逻辑表达式的判断结果
*             @arg true： 表示LXTAL ready置位
*             @arg false：表示LXTAL ready未置位
*/
__STATIC_INLINE bool std_rcc_get_lxtal_ready(void)        
{
    return((RCC->AWCR & RCC_AWCR_LXTALRDY) == RCC_AWCR_LXTALRDY);
}

/** 
* @brief  LXTAL时钟驱动模式选择
* @param  lxtal_drv_mode LXTAL驱动模式选择
*             @arg RCC_LXTAL_DRIVE_MODE_NORMAL： 普通模式
*             @arg RCC_LXTAL_DRIVE_MODE_ENHANCE：增强模式
* @retval 无
*/
__STATIC_INLINE void std_rcc_lxtal_drive_mode_config(uint32_t lxtal_drv_mode) 
{
    MODIFY_REG(RCC->AWCR, RCC_AWCR_LXTAL_DRV_MODE, (lxtal_drv_mode));
}


/**
* @brief  配置LXTAL时钟驱动能力
* @param  drive_level LXTAL时钟驱动能力参数
*             @arg  RCC_LXTAL_DRIVE_LEVEL0
*             @arg  RCC_LXTAL_DRIVE_LEVEL1
*             @arg  RCC_LXTAL_DRIVE_LEVEL2
*             @arg  RCC_LXTAL_DRIVE_LEVEL3
* @note   调用该函数前应先调用std_pmu_vaon_write_enable(void)，解除RCC_AWCR的写保护
* @retval 无
*/
__STATIC_INLINE void std_rcc_lxtal_drive_config(uint32_t drive_level) 
{
    MODIFY_REG(RCC->AWCR, RCC_AWCR_LXTAL_DRV, (drive_level));
}  


/** 
* @brief  配置LXTAL时钟稳定周期
* @param  drive_stabc LXTAL时钟稳定周期
*             @arg  RCC_LXTAL_STAB_SEL_256
*             @arg  ...
*             @arg  RCC_LXTAL_STAB_SEL_16384
* @note   调用该函数前应先调用std_pmu_vaon_write_enable(void)，解除RCC_AWCR的写保护
* @retval 无
*/
__STATIC_INLINE void std_rcc_lxtal_stabc_config(uint32_t drive_stabc)
{
    MODIFY_REG(RCC->AWCR, RCC_AWCR_LXTAL_STAB_SEL, (drive_stabc));
}


/** 
* @brief  使能LXTAL CSS
* @note   LXTAL CSS一旦使能则无法更改，只有检测到LXTAL CSS时，才可清除该位
* @retval 无
*/
__STATIC_INLINE void std_rcc_lxtal_css_enable(void)
{
    RCC->AWCR |= RCC_AWCR_LXTAL_CSSON;
}  


/** 
* @brief  禁止LXTAL CSS
* @note   禁止LXTAL CSS功能后，LXTAL_CSSD位会被清除
* @retval 无
*/
__STATIC_INLINE void std_rcc_lxtal_css_disable(void)
{
    RCC->AWCR &= ~RCC_AWCR_LXTAL_CSSON;
} 


/** 
* @brief  使能RCC中断
* @param  interrupt 使能RCC中断源的信息
*             @arg  RCC_INTERRUPT_LXTAL_CSS

* @retval 无
*/
__STATIC_INLINE void std_rcc_interrupt_enable(uint32_t interrupt)     
{
    RCC->IER |= (interrupt);
}


/** 
* @brief  关闭RCC中断
* @param  interrupt 关闭RCC中断源的信息
*             @arg  RCC_INTERRUPT_LXTAL_CSS
* @retval 无
*/
__STATIC_INLINE void std_rcc_interrupt_disable(uint32_t interrupt)    
{
    RCC->IER &= (~(interrupt));
}


/**
* @brief  获取RCC中断使能状态
* @param  interrupt RCC中断源信息
*             @arg  RCC_INTERRUPT_LXTAL_CSS
* @retval bool 返回输入中断标志置位状态
*             @arg true： 表示指定的中断使能
*             @arg false：表示指定的中断未使能
*/
__STATIC_INLINE bool std_rcc_get_interrupt_enable(uint32_t interrupt)    
{
    return((RCC->IER & (interrupt)) == (interrupt));
}

/**
* @brief  获取RCC中断标志状态
* @param  flag RCC中断标志信息
*             @arg  RCC_FLAG_LXTAL_CSS
* @retval bool 返回输入中断标志置位状态
*             @arg true： 表示指定的中断标志置位
*             @arg false：表示指定的中断标志未置位
             
*/
__STATIC_INLINE bool std_rcc_get_flag(uint32_t flag) 
{
    return((RCC->ISR & (flag)) == (flag));
}

/** 
* @brief  清除RCC标志
* @param  flags 清除标志位
*             @arg  RCC_CLEAR_LXTAL_CSS
* @retval 无
*/
__STATIC_INLINE void std_rcc_clear_flag(uint32_t flags)   
{
    RCC->ICR = (flags);
}

/** 
* @brief  使能RCL时钟
* @note   使能RCL后，软件应等待RCLRDY标志置位后，再使用该时钟
* @retval 无
*/
__STATIC_INLINE void std_rcc_rcl_enable(void)
{
    RCC->CSR2 |= RCC_CSR2_RCLON;
}          

/** 
* @brief  关闭RCL时钟
* @note   如果RCL为系统时钟源，则其不能被停止。此时用户应先将系统时钟源切换为其他时钟，再关闭该时钟源
* @note   当关闭RCL时，需等待RCLRDY标志清零
* @retval 无
*/
__STATIC_INLINE void std_rcc_rcl_disable(void) 
{
    RCC->CSR2 &= (~RCC_CSR2_RCLON);
}        

/** 
* @brief  获取RCL ready标志
* @retval bool 返回逻辑表达式的判断结果
*             @arg true： 表示RCL ready置位
*             @arg false：表示RCL ready未置位
*/
__STATIC_INLINE bool std_rcc_get_rcl_ready(void)          
{
    return((RCC->CSR2 & RCC_CSR2_RCLRDY) == RCC_CSR2_RCLRDY);
}

/** 
* @brief  获取复位标志
* @param  reset_flag 指定要获取的复位标志
*             @arg RCC_RESET_FLAG_LOCKUP
*             @arg RCC_RESET_FLAG_NRST  
*             @arg RCC_RESET_FLAG_POR   
*             @arg RCC_RESET_FLAG_SW    
*             @arg RCC_RESET_FLAG_IWDG  
*             @arg RCC_RESET_FLAG_PVD   
*             @arg RCC_RESET_FLAG_ALL   
* @retval bool 返回逻辑表达式的判断结果
*             @arg true：表示指定的复位标志置位
*             @arg false：表示指定的复位标志未置位
*/
__STATIC_INLINE bool std_rcc_get_reset_flag(uint32_t reset_flag)            
{
    return((RCC->CSR2 & (reset_flag)) == (reset_flag));
} 

/** 
* @brief  清除复位标志
* @note   该函数将清除所有复位标志
* @retval 无
*/
__STATIC_INLINE void std_rcc_clear_reset_flags(void)           
{
    RCC->CSR2 |= RCC_CSR2_RMVF;
}


/** 
* @brief  配置NRST端口功能
* @param  mode NRST功能参数
*             @arg RCC_NRST_PIN_NRST：NRST端口
*             @arg RCC_NRST_PIN_GPIO：GPIO端口
* @retval 无
*/
__STATIC_INLINE void std_rcc_set_nrst_mode(uint32_t mode)           
{
    MODIFY_REG(RCC->CSR2, RCC_CSR2_NRST_MODE, (mode));
}


/** 
* @brief  获取NRST端口功能参数
* @retval uint32_t 返回NRST功能参数
*             @arg RCC_NRST_PIN_NRST：NRST端口
*             @arg RCC_NRST_PIN_GPIO：GPIO端口
*/
__STATIC_INLINE uint32_t std_rcc_get_nrst_mode(void)           
{
    return (RCC->CSR2 & RCC_CSR2_NRST_MODE);
}


/** 
* @brief  GPIO端口时钟使能
* @param  gpiox_clock 指定使能的GPIO时钟
*             @arg RCC_PERIPH_CLK_GPIOA
*             @arg RCC_PERIPH_CLK_GPIOB
*             @arg RCC_PERIPH_CLK_GPIOF
* @retval 无
*/
__STATIC_INLINE void std_rcc_gpio_clk_enable(uint32_t gpiox_clock)
{
    RCC->IOPEN |= gpiox_clock; 
    
    /* RCC外围时钟启用后的延迟 */  
    __NOP(); __NOP(); __NOP(); 
}

/** 
* @brief  GPIO端口时钟禁止
* @param  gpiox_clock 指定禁止的GPIO时钟
*             @arg RCC_PERIPH_CLK_GPIOA
*             @arg RCC_PERIPH_CLK_GPIOB
*             @arg RCC_PERIPH_CLK_GPIOF
* @retval 无
*/
__STATIC_INLINE void std_rcc_gpio_clk_disable(uint32_t gpiox_clock) 
{
    RCC->IOPEN &= (~(gpiox_clock)); 
    
    /* RCC外围时钟启用后的延迟 */  
    __NOP(); __NOP(); __NOP(); 
}

/** 
* @brief  GPIO端口复位
* @param  gpiox_rst 指定复位的GPIO端口
*             @arg RCC_PERIPH_RESET_GPIO_ALL
*             @arg RCC_PERIPH_RESET_GPIOA
*             @arg RCC_PERIPH_RESET_GPIOB
*             @arg RCC_PERIPH_RESET_GPIOF
* @retval 无
*/
__STATIC_INLINE void std_rcc_gpio_reset(uint32_t gpiox_rst)
{
    RCC->IOPRST |= (gpiox_rst);
    RCC->IOPRST &= (~(gpiox_rst));
}         

/** 
* @brief  AHB外设时钟使能
* @param  periph_clock 指定使能的AHB外设时钟
*             @arg RCC_PERIPH_CLK_CRC  
*             @arg RCC_PERIPH_CLK_DMA
* @retval 无
*/
__STATIC_INLINE void std_rcc_ahb_clk_enable(uint32_t periph_clock)
{
    RCC->AHBEN |= periph_clock;
    
    /* RCC外围时钟启用后的延迟 */    
    __NOP(); __NOP(); __NOP(); 
}   

/** 
* @brief  AHB外设时钟禁止
* @param  periph_clock 指定禁止的AHB外设时钟
*             @arg RCC_PERIPH_CLK_CRC 
*             @arg RCC_PERIPH_CLK_DMA 
* @retval 无
*/
__STATIC_INLINE void std_rcc_ahb_clk_disable(uint32_t periph_clock)            
{
    RCC->AHBEN &= (~(periph_clock));
}

/** 
* @brief  AHB外设复位
* @param  periph_rst 指定复位的AHB外设
*             @arg RCC_PERIPH_RESET_CRC
*             @arg RCC_PERIPH_RESET_DMA
* @retval 无
*/
__STATIC_INLINE void std_rcc_ahb_reset(uint32_t periph_rst)
{
    RCC->AHBRST |= (periph_rst);
    RCC->AHBRST &= (~(periph_rst));
}       

/** 
* @brief  APB外设1时钟使能
* @param  periph_clock 指定使能的APB外设1时钟
*             @arg RCC_PERIPH_CLK_TIM3   
*             @arg RCC_PERIPH_CLK_TIM8
*             @arg RCC_PERIPH_CLK_RTC
*             @arg RCC_PERIPH_CLK_SPI2
*             @arg RCC_PERIPH_CLK_UART2
*             @arg RCC_PERIPH_CLK_LPUART1
*             @arg RCC_PERIPH_CLK_I2C1  
*             @arg RCC_PERIPH_CLK_PMU       
*             @arg RCC_PERIPH_CLK_LPTIM1 
* @retval 无
*/
__STATIC_INLINE void std_rcc_apb1_clk_enable(uint32_t periph_clock)
{
    RCC->APBEN1 |= periph_clock;
    
    /* RCC外围时钟启用后的延迟 */    
    __NOP(); __NOP(); __NOP(); 
}

/** 
* @brief  APB外设1时钟禁止
* @param  periph_clock 指定禁止的APB外设1时钟
*             @arg RCC_PERIPH_CLK_TIM3 
*             @arg RCC_PERIPH_CLK_TIM8
*             @arg RCC_PERIPH_CLK_RTC
*             @arg RCC_PERIPH_CLK_SPI2
*             @arg RCC_PERIPH_CLK_UART2
*             @arg RCC_PERIPH_CLK_LPUART1
*             @arg RCC_PERIPH_CLK_I2C1      
*             @arg RCC_PERIPH_CLK_PMU      
*             @arg RCC_PERIPH_CLK_LPTIM1 
* @retval 无
*/
__STATIC_INLINE void std_rcc_apb1_clk_disable(uint32_t periph_clock)            
{
    RCC->APBEN1 &= (~(periph_clock));
}

/** 
* @brief  APB外设1复位
* @param  periph_rst 指定复位的APB外设1
*             @arg RCC_PERIPH_RESET_TIM3 
*             @arg RCC_PERIPH_RESET_TIM8
*             @arg RCC_PERIPH_RESET_SPI2
*             @arg RCC_PERIPH_RESET_UART2
*             @arg RCC_PERIPH_RESET_LPUART1
*             @arg RCC_PERIPH_RESET_I2C1
*             @arg RCC_PERIPH_RESET_LPTIM1 
* @retval 无
*/
__STATIC_INLINE void std_rcc_apb1_reset(uint32_t periph_rst)
{
    RCC->APBRST1 |= (periph_rst);
    RCC->APBRST1 &= (~(periph_rst));
}       

/** 
* @brief  APB外设2时钟使能
* @param  periph_clock 指定使能的APB外设2时钟
*             @arg RCC_PERIPH_CLK_COMP
*             @arg RCC_PERIPH_CLK_TIM1   
*             @arg RCC_PERIPH_CLK_SPI1  
*             @arg RCC_PERIPH_CLK_UART1
*             @arg RCC_PERIPH_CLK_ADC    
*             @arg RCC_PERIPH_CLK_DBG
* @retval 无
*/
__STATIC_INLINE void std_rcc_apb2_clk_enable(uint32_t periph_clock)
{
    RCC->APBEN2 |= periph_clock;
    
    /* RCC外围时钟启用后的延迟 */    
    __NOP(); __NOP(); __NOP(); 
}

/** 
* @brief  APB外设2时钟禁止
* @param  periph_clock 指定禁止的APB外设2时钟
*             @arg RCC_PERIPH_CLK_COMP
*             @arg RCC_PERIPH_CLK_TIM1   
*             @arg RCC_PERIPH_CLK_SPI1  
*             @arg RCC_PERIPH_CLK_UART1 
*             @arg RCC_PERIPH_CLK_ADC    
*             @arg RCC_PERIPH_CLK_DBG
* @retval 无
*/
__STATIC_INLINE void std_rcc_apb2_clk_disable(uint32_t periph_clock)            
{
    RCC->APBEN2 &= (~(periph_clock));
}

/** 
* @brief  APB外设2复位
* @param  periph_rst 指定复位的APB外设2
*             @arg RCC_PERIPH_RESET_COMP   
*             @arg RCC_PERIPH_RESET_TIM1   
*             @arg RCC_PERIPH_RESET_SPI1  
*             @arg RCC_PERIPH_RESET_UART1 
*             @arg RCC_PERIPH_RESET_ADC    
*             @arg RCC_PERIPH_RESET_DBG  
* @retval 无
*/
__STATIC_INLINE void std_rcc_apb2_reset(uint32_t periph_rst)
{
    RCC->APBRST2 |= (periph_rst);
    RCC->APBRST2 &= (~(periph_rst));
}       

/** 
* @brief  使能LOCKUP复位
* @retval 无
*/
__STATIC_INLINE void std_rcc_lockup_reset_enable(void)
{
    RCC->CSR2 |= RCC_CSR2_LOCKUP_RSTEN;
}

/** 
* @brief  禁止LOCKUP复位
* @retval 无
*/
__STATIC_INLINE void std_rcc_lockup_reset_disable(void)
{
    RCC->CSR2 &= (~RCC_CSR2_LOCKUP_RSTEN);
}

/** 
* @brief  LPTIM1时钟源选择
* @param  lptim1clk_select LPTIM1时钟源
*             @arg RCC_LPTIM1_ASYNC_CLK_SRC_PCLK
*             @arg RCC_LPTIM1_ASYNC_CLK_SRC_RCL
*             @arg RCC_LPTIM1_ASYNC_CLK_SRC_MCO
*             @arg RCC_LPTIM1_ASYNC_CLK_SRC_LXTAL
* @retval 无
*/
__STATIC_INLINE void std_rcc_set_lptim1clk_source(uint32_t lptim1clk_select)
{
    MODIFY_REG(RCC->CLKSEL, RCC_CLKSEL_LPTIM1_SEL, (lptim1clk_select));
}       

/** 
* @brief  获取LPTIM1时钟源
* @retval uint32_t 返回LPTIM1时钟源信息
*             @arg RCC_LPTIM1_ASYNC_CLK_SRC_PCLK
*             @arg RCC_LPTIM1_ASYNC_CLK_SRC_RCL
*             @arg RCC_LPTIM1_ASYNC_CLK_SRC_MCO
*             @arg RCC_LPTIM1_ASYNC_CLK_SRC_LXTAL
*/
__STATIC_INLINE uint32_t std_rcc_get_lptim1clk_source(void)
{
    return(RCC->CLKSEL & RCC_CLKSEL_LPTIM1_SEL);
} 

/** 
* @brief  LPUART1时钟源选择
* @param  lpuart1clk_select LPUART1时钟源
*             @arg RCC_LPUART1_ASYNC_CLK_SRC_PCLK
*             @arg RCC_LPUART1_ASYNC_CLK_SRC_SYSCLK
*             @arg RCC_LPUART1_ASYNC_CLK_SRC_RCH
*             @arg RCC_LPUART1_ASYNC_CLK_SRC_LXTAL
* @retval 无
*/
__STATIC_INLINE void std_rcc_set_lpuart1clk_source(uint32_t lpuart1clk_select)
{
    MODIFY_REG(RCC->CLKSEL, RCC_CLKSEL_LPUART1_SEL, (lpuart1clk_select));
}       

/** 
* @brief  获取LPUART1时钟源
* @retval uint32_t 返回LPUART1时钟源信息
*             @arg RCC_LPUART1_ASYNC_CLK_SRC_PCLK
*             @arg RCC_LPUART1_ASYNC_CLK_SRC_SYSCLK
*             @arg RCC_LPUART1_ASYNC_CLK_SRC_RCH
*             @arg RCC_LPUART1_ASYNC_CLK_SRC_LXTAL
*/
__STATIC_INLINE uint32_t std_rcc_get_lpuart1clk_source(void)
{
    return(RCC->CLKSEL & RCC_CLKSEL_LPUART1_SEL);
} 


/** 
* @brief  RTC时钟源选择
* @param  rtcclk_select RTC时钟源
*             @arg RCC_RTC_ASYNC_CLK_SRC_NONE
*             @arg RCC_RTC_ASYNC_CLK_SRC_LXTAL
*             @arg RCC_RTC_ASYNC_CLK_SRC_RCL
* @note   调用该函数前应先调用std_pmu_vaon_write_enable(void)，解除RCC_AWCR的写保护
* @retval 无
*/
__STATIC_INLINE void std_rcc_set_rtcclk_source(uint32_t rtcclk_select)
{
    MODIFY_REG(RCC->AWCR, RCC_AWCR_RTCSEL, (rtcclk_select));
}       

/** 
* @brief  获取RTC时钟源
* @retval uint32_t 返回RTC时钟源信息
*             @arg RCC_RTC_ASYNC_CLK_SRC_NONE
*             @arg RCC_RTC_ASYNC_CLK_SRC_LXTAL
*             @arg RCC_RTC_ASYNC_CLK_SRC_RCL 
*/
__STATIC_INLINE uint32_t std_rcc_get_rtcclk_source(void)
{
    return(RCC->AWCR & RCC_AWCR_RTCSEL);
} 


/** 
* @brief  使能RTC时钟
* @note   调用该函数前应先调用std_pmu_vaon_write_enable(void)，解除RCC_AWCR的写保护
* @note   应先选择RTC时钟源后再调用该函数使能RTC KCLK时钟
* @retval 无
*/
__STATIC_INLINE void std_rcc_rtc_enable(void) 
{
    RCC->AWCR |= RCC_AWCR_RTCEN;
}        

/** 
* @brief  关闭RTC时钟
* @note   调用该函数前应先调用std_pmu_vaon_write_enable(void)，解除RCC_AWCR的写保护
* @retval 无
*/
__STATIC_INLINE void std_rcc_rtc_disable(void)       
{
    RCC->AWCR &= (~RCC_AWCR_RTCEN);
}


/**
* @brief  使能RCH常开功能
* @note   使能后在Stop模式下，RCH仍旧保持打开状态，可用作LPUART1等外设工作时钟，避免因RCH启动时间而减慢通讯速度
* @note   此功能的置位和清除对RCHON位无影响
* @retval 无
*/
__STATIC_INLINE void std_rcc_rchawon_enable(void)
{
    RCC->CSR1 |= RCC_CSR1_RCH_AWON;
}

/**
* @brief  禁止RCH常开功能
* @note   此功能的置位和清除对RCHON位无影响
* @retval 无
*/
__STATIC_INLINE void std_rcc_rchawon_disable(void)
{
     RCC->CSR1 &= (~RCC_CSR1_RCH_AWON);
}   


/** 
* @brief  VCORE_AON 域复位
* @note   此函数用于重置RTC/TAMP外设（包括备份寄存器）和 RCC_AWCR部分控制位
* @note   调用该函数前应先调用std_pmu_vaon_write_enable(void)，解除RCC_AWCR的写保护
* @retval 无
*/
__STATIC_INLINE void std_rcc_vcore_aon_reset(void)  
{
    RCC->AWCR |= RCC_AWCR_AW_RST;
    RCC->AWCR &= (~RCC_AWCR_AW_RST);
}             


/** 
* @brief  写RCL校准值
* @param  cal_value RCL校准值
* @retval 无
*/
__STATIC_INLINE void std_rcc_write_rcl_calibration(uint32_t cal_value)
{
    RCC->RCLCAL = cal_value;
}

/** 
* @brief  读取RCL校准值
* @retval uint32_t RCL校准值
*/
__STATIC_INLINE uint32_t std_rcc_read_rcl_calibration(void)
{
    return(RCC->RCLCAL);
}

/** 
* @brief  写RCH时钟粗调值
* @param  cal_value RCH时钟粗调值
* @retval 无
*/
__STATIC_INLINE void std_rcc_write_rch_coarse_calibration(uint32_t cal_value)
{
    MODIFY_REG(RCC->RCHCAL, RCC_RCHCAL_RCH_CAL_COARSE, cal_value << RCC_RCHCAL_RCH_CAL_COARSE_POS);
}

/** 
* @brief  读取RCH时钟粗调值
* @retval uint32_t RCH时钟粗调值
*/
__STATIC_INLINE uint32_t std_rcc_read_rch_coarse_calibration(void)
{
    return((RCC->RCHCAL & RCC_RCHCAL_RCH_CAL_COARSE) >> RCC_RCHCAL_RCH_CAL_COARSE_POS);
}

/** 
* @brief  写RCH时钟微调值
* @param  trim_value  RCH时钟微调值
* @retval 无
*/
__STATIC_INLINE void std_rcc_write_rch_fine_calibration(uint32_t trim_value)
{
    MODIFY_REG(RCC->RCHCAL, RCC_RCHCAL_RCH_CAL_FINE, trim_value);
}

/** 
* @brief  读取RCH时钟微调值
* @retval uint32_t RCH时钟微调值
*/
__STATIC_INLINE uint32_t std_rcc_read_rch_fine_calibration(void)
{
    return(RCC->RCHCAL & RCC_RCHCAL_RCH_CAL_FINE);
}


/* 获取时钟频率函数 */
uint32_t std_rcc_get_sysclkfreq(void);
uint32_t std_rcc_get_hclkfreq(void);
uint32_t std_rcc_get_pclkfreq(void); 

uint32_t std_rcc_get_rchfreq(void);
uint32_t std_rcc_get_lpuart1freq(void);


/** 
* @} 
*/


#ifdef __cplusplus
}
#endif

/**
* @} 
*/  

/**
* @}
*/

#endif /* STD_RCC_H */
